@@ -17,6 +17,58 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
+
+/**
+ * SECTION:anjuta-shell
+ * @title: AnjutaShell
+ * @short_description: Application shell interface
+ * @see_also:
+ * @stability: Unstable
+ * @include: libanjuta/anjuta-shell.h
+ * 
+ * Shell is the playground where plugins are loaded and their UI
+ * widgets shown. It is also a place where plugins export objects for letting
+ * other pluings to use. Plugins are loaded into shell on demand, but some
+ * plugins are loaded on startup (such as help and text editor plugin).
+ * Demand to load a plugin can be made by requesting for a primary inferface
+ * using anjuta_shell_get_interface() or anjuta_shell_get_object().
+ * 
+ * Plugins can add widgets in shell with
+ * anjuta_shell_add_widget() and remove with anjuta_shell_remove_widget()
+ * functions.
+ * 
+ * In Anjuta, shell is implemented using an advanced widget docking system,
+ * allowing plugin widgets to dock, undock and layout in any fashion. Dock
+ * layout is also maintained internally and is transparent to plugin
+ * implementations.
+ * 
+ * #AnjutaShell allows plugins to export arbitrary objects as <emphasis>
+ * values</emphasis> in its <emphasis>Values System</emphasis>. "value_added"
+ * and "value_removed" signals are emitted when a value is added to or
+ * removed from the <emphasis>Values System</emphasis>, hence notifying
+ * plugins of its state. However, plugins should really not connect directly
+ * to these signals, because they are emitted for all values
+ * and not just for the values the plugin is interested in. Instead,
+ * to monitor specific <emphasis>Values</emphasis>, plugins should
+ * setup watches using anjuta_plugin_add_watch().
+ * 
+ * <emphasis>Values</emphasis> are added, get or removed with
+ * anjuta_shell_add_value() and anjuta_shell_get_value() or
+ * anjuta_shell_remove_value(). There multi-valued equivalent functions
+ * can be used to manipulate multiple values at once.
+ * 
+ * <emphasis>Values</emphasis> are identified with names. Since <emphasis>
+ * Values</emphasis> are effectively variables, their names should follow
+ * the standard GNOME variable naming convention and should be as descriptive
+ * as possible (e.g project_root_directory, project_name etc.). It is also
+ * essential that meaningful prefix be given to names so that <emphasis>
+ * Values</emphasis> are easily grouped (e.g all values exported by a 
+ * project manager should start with project_ prefix).
+ * 
+ * Plugins can find other plugins with anjuta_shell_get_object() or 
+ * anjuta_shell_get_interface() based on their primary interfaces.
+ */
+
 #include <config.h>
 #include <string.h>
 #include <gobject/gvaluecollector.h>
@@ -122,7 +174,7 @@ anjuta_shell_thaw (AnjutaShell *shell, GError **error)
 	if (freeze_count <= 0)
 	{
 		/* Add all pending widgets */
-		DEBUG_PRINT ("Thawing shell ...");
+		/* DEBUG_PRINT ("Thawing shell ..."); */
 		
 		GQueue *queue;
 		queue = g_object_get_data (G_OBJECT (shell), "__widget_queue");
@@ -646,6 +698,24 @@ anjuta_shell_get_plugin_manager (AnjutaShell *shell, GError **error)
 	return ANJUTA_SHELL_GET_IFACE (shell)->get_plugin_manager (shell, error);
 }
 
+/**
+ * anjuta_shell_get_profile_manager:
+ * @shell: A #AnjutaShell interface
+ * @error: Error propagation object
+ *
+ * Retrieves the #AnjutaProfileManager object associated with the shell.
+ *
+ * Return value: The #AnjutaProfileManager object.
+ */
+AnjutaProfileManager*
+anjuta_shell_get_profile_manager (AnjutaShell *shell, GError **error)
+{
+	g_return_val_if_fail (shell != NULL, NULL);
+	g_return_val_if_fail (ANJUTA_IS_SHELL (shell), NULL);
+
+	return ANJUTA_SHELL_GET_IFACE (shell)->get_profile_manager (shell, error);
+}
+
 void
 anjuta_shell_session_save (AnjutaShell *shell, const gchar *session_directory,
 						   GError **error)
@@ -679,7 +749,7 @@ anjuta_shell_session_load (AnjutaShell *shell, const gchar *session_directory,
 	/* Do not allow multiple session loadings at once. Could be a trouble */
 	if (g_object_get_data (G_OBJECT (shell), "__session_loading"))
 	{
-		DEBUG_PRINT ("A session load is requested in the middle of another!!");
+		/* DEBUG_PRINT ("A session load is requested in the middle of another!!"); */
 		return;
 	}
 	g_object_set_data (G_OBJECT (shell), "__session_loading", "1");
@@ -706,6 +776,14 @@ anjuta_shell_save_prompt (AnjutaShell *shell,
 	g_signal_emit_by_name (shell, "save-prompt", save_prompt);
 }
 
+void
+anjuta_shell_notify_exit (AnjutaShell *shell,
+						  GError **error)
+{
+	g_return_if_fail (ANJUTA_IS_SHELL (shell));
+	g_signal_emit_by_name (shell, "exiting");
+}
+
 static void
 anjuta_shell_base_init (gpointer gclass)
 {
@@ -755,6 +833,13 @@ anjuta_shell_base_init (gpointer gclass)
 			      anjuta_cclosure_marshal_VOID__OBJECT,
 			      G_TYPE_NONE, 1,
 			      G_TYPE_OBJECT);
+		g_signal_new ("exiting",
+			      ANJUTA_TYPE_SHELL,
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (AnjutaShellIface, exiting),
+			      NULL, NULL,
+			      anjuta_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE, 0);
 		initialized = TRUE;
 	}
 }
