@@ -39,10 +39,21 @@ extern void libanjuta_iface_cclosure_marshal_VOID__INT_CHAR (GClosure     *closu
                                                              gpointer      invocation_hint,
                                                              gpointer      marshal_data);
 
-/* VOID:STRING (./libanjuta-iface-marshallers.list:7) */
+/* VOID:POINTER (./libanjuta-iface-marshallers.list:7) */
+#define libanjuta_iface_cclosure_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER
+
+/* VOID:STRING (./libanjuta-iface-marshallers.list:8) */
 #define libanjuta_iface_cclosure_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING
 
-/* VOID:STRING,UINT,UINT (./libanjuta-iface-marshallers.list:8) */
+/* VOID:STRING,STRING (./libanjuta-iface-marshallers.list:9) */
+extern void libanjuta_iface_cclosure_marshal_VOID__STRING_STRING (GClosure     *closure,
+                                                                  GValue       *return_value,
+                                                                  guint         n_param_values,
+                                                                  const GValue *param_values,
+                                                                  gpointer      invocation_hint,
+                                                                  gpointer      marshal_data);
+
+/* VOID:STRING,UINT,UINT (./libanjuta-iface-marshallers.list:10) */
 extern void libanjuta_iface_cclosure_marshal_VOID__STRING_UINT_UINT (GClosure     *closure,
                                                                      GValue       *return_value,
                                                                      guint         n_param_values,
@@ -50,10 +61,18 @@ extern void libanjuta_iface_cclosure_marshal_VOID__STRING_UINT_UINT (GClosure
                                                                      gpointer      invocation_hint,
                                                                      gpointer      marshal_data);
 
-/* VOID:UINT (./libanjuta-iface-marshallers.list:9) */
+/* VOID:UINT (./libanjuta-iface-marshallers.list:11) */
 #define libanjuta_iface_cclosure_marshal_VOID__UINT	g_cclosure_marshal_VOID__UINT
 
-/* VOID:VOID (./libanjuta-iface-marshallers.list:10) */
+/* VOID:UINT,UINT (./libanjuta-iface-marshallers.list:12) */
+extern void libanjuta_iface_cclosure_marshal_VOID__UINT_UINT (GClosure     *closure,
+                                                              GValue       *return_value,
+                                                              guint         n_param_values,
+                                                              const GValue *param_values,
+                                                              gpointer      invocation_hint,
+                                                              gpointer      marshal_data);
+
+/* VOID:VOID (./libanjuta-iface-marshallers.list:13) */
 #define libanjuta_iface_cclosure_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID
 
 G_END_DECLS
